@@ -38,8 +38,8 @@ struct _HTMLTableCell {
 
 	gint fixed_width;
 	gint fixed_height;
-	gboolean percent_width  : 1;
-	gboolean percent_height : 1;
+	guint percent_width  : 1;
+	guint percent_height : 1;
 	gboolean no_wrap;
 	gboolean heading;
 
@@ -54,6 +54,8 @@ struct _HTMLTableCell {
 
 	HTMLImagePointer *bgPixmap;
 	gboolean have_bgPixmap;
+
+	HTMLDirection dir;
 };
 
 struct _HTMLTableCellClass {
